@@ -261,7 +261,12 @@ class Gateway():
             commeoSensors = dict([(id, SensorDevice(self, id , True) )for id in commandCommeoSensors.ids])
         
 
-        self.devices = iveoDevices | commeoActors | commeoGroups | commeoSenders | commeoSenSims | commeoSensors
+        self.devices.update(iveoDevices) 
+        self.devices.update(commeoActors) 
+        self.devices.update(commeoGroups) 
+        self.devices.update(commeoSenders) 
+        self.devices.update(commeoSenSims) 
+        self.devices.update(commeoSensors)
         
         self.list_devices() 
        
