@@ -1,7 +1,9 @@
 from enum import Enum
 from os import wait
+from selve import commands
+from selve.commandClasses.command import CommeoCommandDevice
 
-from selve.protocol import CommunicationType, DayMode, DeviceClass, DeviceCommandTypes, DeviceState, MethodCall, MovementState, ScanState, ServiceState
+from selve.protocol import CommandType, CommunicationType, DayMode, DeviceClass, DeviceCommandTypes, DeviceState, MethodCall, MovementState, ScanState, ServiceState
 from selve.protocol import ParameterType
 from selve.protocol import DeviceType
 from selve.commands import Commands, CommeoCommandCommand, CommeoDeviceCommand, CommeoEventCommand, CommeoGroupCommand, CommeoParamCommand, CommeoSenSimCommand, CommeoSenderCommand, CommeoSensorCommand, CommeoServiceCommand
@@ -167,6 +169,7 @@ class ActorDevice(Device):
         self.rainAlarm = command.rainAlarm
         self.freezingAlarm = command.freezingAlarm
         self.dayMode = command.dayMode
+        return command
 
     def setDeviceFunction(self, func):
         command = CommeoDeviceSetFunction(self.ID, func)
@@ -188,4 +191,112 @@ class ActorDevice(Device):
     def setDeviceManual(self):
         command = CommeoDeviceWriteManual(self.ID, self.rfAddress, self.name, self.device_type)
         command.execute(self.gateway)
+
+    def executeCommand(self, command, commandType = DeviceCommandTypes.MANUAL, parameter = 0):
+        command = CommeoCommandDevice(self.ID, command, commandType, parameter)
+        command.execute(self.gateway)
+        return command
+
+    def stop(self, forced=False):
+        if forced:
+            type=DeviceCommandTypes.FORCED
+        else:
+            type=DeviceCommandTypes.MANUAL
+
+        self.executeCommand(CommandType.STOP, type)
+
+    def moveDown(self, forced=False):
+        if forced:
+            type=DeviceCommandTypes.FORCED
+        else:
+            type=DeviceCommandTypes.MANUAL
+
+        self.executeCommand(CommandType.DRIVEDOWN, type)
     
+    def moveUp(self, forced=False):
+        if forced:
+            type=DeviceCommandTypes.FORCED
+        else:
+            type=DeviceCommandTypes.MANUAL
+
+        self.executeCommand(CommandType.DRIVEUP, type)
+    
+    def moveIntermediatePosition1(self, forced=False):
+        if forced:
+            type=DeviceCommandTypes.FORCED
+        else:
+            type=DeviceCommandTypes.MANUAL
+
+        self.executeCommand(CommandType.DRIVEPOS1, type)
+
+    def moveIntermediatePosition2(self, forced=False):
+        if forced:
+            type=DeviceCommandTypes.FORCED
+        else:
+            type=DeviceCommandTypes.MANUAL
+
+        self.executeCommand(CommandType.DRIVEPOS2, type)
+    
+    def driveToPos(self, position, forced=False):
+        if forced:
+            type=DeviceCommandTypes.FORCED
+        else:
+            type=DeviceCommandTypes.MANUAL
+
+        self.executeCommand(CommandType.DRIVEPOS, type, position)
+
+    def stepUp(self, degrees, forced=False):
+        if forced:
+            type=DeviceCommandTypes.FORCED
+        else:
+            type=DeviceCommandTypes.MANUAL
+
+        self.executeCommand(CommandType.STEPUP, type, degrees)
+
+    def stepDown(self, degrees, forced=False):
+        if forced:
+            type=DeviceCommandTypes.FORCED
+        else:
+            type=DeviceCommandTypes.MANUAL
+
+        self.executeCommand(CommandType.STEPDOWN, type, degrees)
+
+    def setAutomatic(self, autoOn, forced=False):
+        if forced:
+            type=DeviceCommandTypes.FORCED
+        else:
+            type=DeviceCommandTypes.MANUAL
+
+        if autoOn:
+            self.executeCommand(CommandType.AUTOON, type)
+        else:
+            self.executeCommand(CommandType.AUTOOFF, type)
+
+    def scanStart(self):
+        commandStart = CommeoDeviceScanStart()
+        commandResult = CommeoDeviceScanResult()
+        commandStart.execute(self.gateway)
+        commandResult.execute(self.gateway)
+        while commandResult.scanState == ScanState.RUN or commandResult.scanState == ScanState.VERIFY:
+            wait(commandResult.timeLeft+1)
+            commandResult.execute(self.gateway)
+        if commandResult.scanState == ScanState.END_SUCCESS:
+            if commandResult.noNewDevices > 0:
+                return commandResult.foundIds
+        return {}
+
+    def saveDevice(self):
+        command = CommeoDeviceSave(self.ID)
+        command.execute(self.gateway)
+        if command.executed:
+            _LOGGER.info("Device saved")
+        else:
+            _LOGGER.info("Device saving failed")
+
+    def deleteDevice(self):
+        command = CommeoDeviceDelete(self.ID)
+        command.execute(self.gateway)
+        if command.executed:
+            _LOGGER.info("Device deleted")
+        else:
+            _LOGGER.info("Device deletion failed")
